==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/cue/translations/cue_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>CUE プラグイン</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>CUE ファイル</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="85"/>
        <source>About CUE Audio Plugin</source>
        <translation>CUE 音響プラグインについて</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="86"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>QMMP CUE 音響プラグイン</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="87"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>CUE プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CUE encoding</source>
        <translation>CUE 文字符号化形式</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Automatic charset detection</source>
        <translation>文字セット自動検知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Language:</source>
        <translation>言語:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="65"/>
        <source>Default encoding:</source>
        <translation>文字符号化形式(初期設定値):</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/cue/translations/cue_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="46"/>
        <source>CUE Plugin</source>
        <translation>CUE プラグイン</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="49"/>
        <source>CUE Files</source>
        <translation>CUE ファイル</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="100"/>
        <source>About CUE Audio Plugin</source>
        <translation>CUE 音響プラグインについて</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="101"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>QMMP CUE 音響プラグイン</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="102"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>CUE プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>共通設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>CUE シートに間違いがあってもできるだけ読み込む</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>CUE 文字符号化形式</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>文字セット自動検知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>言語:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>文字符号化形式(初期設定値):</translation>
    </message>
</context>
</TS>
